import { RedocRawOptions, OperationModel, StoreState, RedocNormalizedOptions, SpecStore, MarkerService, SearchStore, IMenuItem, ContentItemModel } from 'redoc';
import { ProMenu } from './ProMenu';
import { SearchResultMeta } from './SearchStore';
import { ThemeExtension } from './extendTheme';
import { LicenseInfo } from './check';
import { OpenAPIExternalDocumentation } from 'redoc/typings/types';
export declare type Normalized<T> = {
    [P in keyof T]-?: T[P];
};
export declare type RedocProTheme = RedocRawOptions['theme'] & ThemeExtension;
export declare type RedocProOptionsExt = {
    licenseKey?: string;
    searchMode?: 'default' | 'path-only';
    searchOperationTitleBoost?: number | string;
    searchTagTitleBoost?: number | string;
    searchFieldLevelBoost?: number | string;
    searchAutoExpand?: boolean;
    sideNavStyle?: 'summary-only' | 'path-first';
    showConsole?: boolean;
    hideLogo?: boolean;
    whiteLabel?: boolean;
    layout?: {
        scope: 'all' | 'section' | 'item';
        markdownItemsScope: 'all' | 'section';
        showTag?: boolean;
        showInfoOnEachPage?: boolean;
        showNextButton?: boolean;
    };
    routingStrategy?: 'hash' | 'browser';
    routingBasePath?: string;
    theme?: RedocProTheme;
    downloadSpecUrl?: string;
    ctrlFHijack?: boolean;
    unstable_externalDescription?: string;
};
export declare type RedocProRawOptions = RedocRawOptions & RedocProOptionsExt;
export declare type RedocProNormalizedOptions = RedocNormalizedOptions & Normalized<RedocProOptionsExt>;
export interface ProStoreState extends StoreState {
    tryItOperationId?: string;
    options: RedocProRawOptions;
}
export declare class NestingGroup implements IMenuItem {
    id: string;
    absoluteIdx?: number;
    name: string;
    description?: string;
    type: 'group';
    linkable: boolean;
    items: ContentItemModel[];
    parent?: NestingGroup;
    externalDocs?: OpenAPIExternalDocumentation;
    active: boolean;
    expanded: boolean;
    depth: number;
    level: number;
    constructor(id: string, items: ContentItemModel[], name?: string, linkable?: boolean);
    activate(): void;
    expand(): void;
    collapse(): void;
    deactivate(): void;
}
export declare class ProStore {
    rawOptions: RedocProRawOptions;
    options: RedocProNormalizedOptions;
    menu: ProMenu;
    spec: SpecStore;
    marker: MarkerService;
    private scroll;
    private disposer;
    search?: SearchStore<SearchResultMeta>;
    tryItOperation?: OperationModel;
    resolvedRawSpec: any;
    prevIdx: number;
    l: Promise<LicenseInfo>;
    constructor(spec: any | Array<{
        title: string;
        url: string;
    }>, specUrl?: string, options?: RedocProRawOptions, createIndex?: boolean);
    groupSpecContentItems(spec: SpecStore): void;
    initProOptions(options: RedocProRawOptions): void;
    initSearch(options: RedocProNormalizedOptions, createIndex: boolean): void;
    onDidMount(): void;
    tryItOut(operation?: OperationModel): void;
    resolveSpec(idx: number): Promise<void>;
    observeAllAndRemark(): void;
    remark(change: any): void;
    static fromJS(state: ProStoreState): ProStore;
    toJS(): Promise<ProStoreState>;
    dispose(): void;
    private updateMarkOnMenu;
}
